/*
 * Copyright 2017, Cypress Semiconductor Corporation or a subsidiary of Cypress Semiconductor 
 *  Corporation. All rights reserved. This software, including source code, documentation and  related 
 * materials ("Software"), is owned by Cypress Semiconductor  Corporation or one of its 
 *  subsidiaries ("Cypress") and is protected by and subject to worldwide patent protection  
 * (United States and foreign), United States copyright laws and international treaty provisions. 
 * Therefore, you may use this Software only as provided in the license agreement accompanying the 
 * software package from which you obtained this Software ("EULA"). If no EULA applies, Cypress 
 * hereby grants you a personal, nonexclusive, non-transferable license to  copy, modify, and 
 * compile the Software source code solely for use in connection with Cypress's  integrated circuit 
 * products. Any reproduction, modification, translation, compilation,  or representation of this 
 * Software except as specified above is prohibited without the express written permission of 
 * Cypress. Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO  WARRANTY OF ANY KIND, EXPRESS 
 * OR IMPLIED, INCLUDING,  BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE. Cypress reserves the right to make changes to 
 * the Software without notice. Cypress does not assume any liability arising out of the application 
 * or use of the Software or any product or circuit  described in the Software. Cypress does 
 * not authorize its products for use in any products where a malfunction or failure of the 
 * Cypress product may reasonably be expected to result  in significant property damage, injury 
 * or death ("High Risk Product"). By including Cypress's product in a High Risk Product, the 
 *  manufacturer of such system or application assumes  all risk of such use and in doing so agrees 
 * to indemnify Cypress against all liability.
 */

/** @file
*
* Defines peripherals available for use on CYW920706WCDEVAL, and legacy BCM920706_P49 and BCM920706_B49 boards.
* Use LEGACY_BOARD=1 in the make target for the BCM920706_P49 and BCM920706_B49 boards
* Use B49=1 in the make target for BCM920706_B49 board.
*
*/

#pragma once

/** \addtogroup Platfrom config - Peripherals pin configuration
*   \ingroup HardwareDrivers
*/
/*! @{ */

/******************************************************
 *                   Enumerations
 ******************************************************/

#include "wiced_bt_types.h"
#include "wiced_hal_gpio.h"

extern void platform_led_init( void );

typedef struct
{
    wiced_bt_gpio_numbers_t led_gpio;
    uint32_t led_config;
    uint32_t led_default_state;
}wiced_led_config_t;

typedef enum
{
    WICED_PLATFORM_LED_1,
    WICED_PLATFORM_LED_MAX
}wiced_platform_led_t;

#define HCI_UART_DEFAULT_BAUD   115200   /* default baud rate is 115200, that is max supported by dual-channel Cypress USB bridge */
#define HCI_UART_MAX_BAUD       1000000

#define WICED_GPIO_BUTTON                                   WICED_P00      /* pin for button interrupts */
#define WICED_GPIO_PIN_BUTTON                               WICED_GPIO_BUTTON
#define WICED_GPIO_BUTTON_DEFAULT_STATE              GPIO_PIN_OUTPUT_LOW

/* x can be GPIO_EN_INT_RISING_EDGE or GPIO_EN_INT_FALLING_EDGE or GPIO_EN_INT_BOTH_EDGE */
#define WICED_GPIO_BUTTON_SETTINGS(x)                       ( GPIO_INPUT_ENABLE | GPIO_PULL_DOWN | x )
#define WICED_BUTTON_PRESSED_VALUE                 1

#define WICED_GPIO_PIN_LED1									WICED_P28
#define WICED_GPIO_LED_SETTINGS                   (GPIO_OUTPUT_ENABLE | GPIO_PULL_UP)
#define WICED_GPIO_LED_ON_VAL                     0

#define WICED_PUART_TXD                           WICED_P31      		/* ARM GPIO pin for PUART TXD         */
#define WICED_PUART_RXD                           WICED_P04      		/* ARM GPIO pin for PUART RXD         */
#define WICED_PUART_CTS                           WICED_P03      		/* pin for PUART CTS (I2C_SCL, P3, P29, P35)   */
#define WICED_PUART_RTS                           WICED_P30      		/* pin for PUART RTS (BT_GPIO_7, P30)          */


/* @} */
